@@ -28,6 +28,9 @@ class StandardFunction:
           float: norm of data_vector
 
         """
+        if data_vector is None:
+            return None
+
         data_vector_unit = data_vector.units
         data_vector = data_vector.magnitude
         return np.linalg.norm(data_vector, axis=1).reshape(-1, 1) * data_vector_unit
@@ -44,6 +47,9 @@ class StandardFunction:
           scalar: Maximum of data_vector
 
         """
+        if data_vector is None:
+            return None
+
         return np.max(data_vector)
 
     @staticmethod
@@ -59,6 +65,8 @@ class StandardFunction:
           scalar: absolute maximum of data_vector
 
         """
+        if data_vector is None:
+            return None
 
         return np.max(np.abs(data_vector))
 
@@ -92,6 +100,8 @@ class StandardFunction:
           np.ndarray of ints: indices of the absolute maximum values
 
         """
+        if data_vector is None:
+            return None
 
         return np.argmax(np.abs(data_vector))
 
@@ -108,6 +118,8 @@ class StandardFunction:
           scalar: Minimum of data_vector
 
         """
+        if data_vector is None:
+            return None
 
         return np.min(data_vector)
 
@@ -125,6 +137,8 @@ class StandardFunction:
           This is a scalar if both data_vector_1 and data_vector_2 are scalars.
 
         """
+        if data_vector_1 is None or data_vector_2 is None:
+            return None
 
         return np.multiply(data_vector_1, data_vector_2)
 
@@ -141,6 +155,9 @@ class StandardFunction:
           np.ndarray: absolute value of each element in data_vector
 
         """
+        if data_vector is None:
+            return None
+
         return np.abs(data_vector)
 
     @staticmethod
@@ -154,6 +171,9 @@ class StandardFunction:
         Returns:
 
         """
+        if data_vector is None:
+            return None
+
         return data_vector - data_vector[0]
 
     @staticmethod
@@ -168,6 +188,9 @@ class StandardFunction:
           scalar: value of data_vector at certain index.
 
         """
+        if data_vector is None:
+            return None
+
         return data_vector[index]
 
     @staticmethod
@@ -201,6 +224,9 @@ class StandardFunction:
           np.ndarray: The difference of data_vector_1 and data_vector_2, element-wise.
 
         """
+        if data_vector_1 is None or data_vector_2 is None:
+            return None
+
         return np.subtract(data_vector_1, data_vector_2)
 
     @staticmethod
@@ -216,6 +242,9 @@ class StandardFunction:
           np.ndarray: The sum of data_vector_1 and data_vector_2, element-wise.
 
         """
+        if data_vector_1 is None or data_vector_2 is None:
+            return None
+
         return np.add(data_vector_1, data_vector_2)
 
     @staticmethod
@@ -232,6 +261,8 @@ class StandardFunction:
           This is a sscalar if both data_vector_1 and data_vector_2 are scalars.
 
         """
+        if data_vector_1 is None or data_vector_2 is None:
+            return None
 
         return np.divide(data_vector_1, data_vector_2)
 
@@ -247,6 +278,9 @@ class StandardFunction:
           np.ndarray: Sum of elements over rows.
 
         """
+        if matrix is None:
+            return None
+
         return np.sum(matrix, axis=1)
 
     @staticmethod
@@ -263,6 +297,9 @@ class StandardFunction:
           np.ndarray: absolute value of each element from the difference between data_vector_1 and data_vector_2
 
         """
+        if data_vector_1 is None or data_vector_2 is None:
+            return None
+
         return np.abs(np.subtract(data_vector_1, data_vector_2))
 
     @staticmethod
@@ -279,6 +316,9 @@ class StandardFunction:
           np.ndarray: absolute value of each element from the sum of data_vector_1 and data_vector_2
 
         """
+        if data_vector_1 is None or data_vector_2 is None:
+            return None
+
         return np.abs(np.add(data_vector_1, data_vector_2))
 
     @staticmethod
@@ -294,6 +334,9 @@ class StandardFunction:
           np.ndarray: returns the resultant of the substracted values from data_vector_1 and data_vector_2
 
         """
+        if data_vector_1 is None or data_vector_2 is None:
+            return None
+
         return np.linalg.norm(np.subtract(data_vector_1, data_vector_2),axis=1)
 
     @staticmethod
@@ -311,6 +354,9 @@ class StandardFunction:
           scalar: Returns timestamp where data_vector is less than zero for the first time.
 
         """
+        if data_vector is None:
+            return None
+
         time_where_data_vector_less_zero = time[(np.where(data_vector < 0))]
         return time_where_data_vector_less_zero[0] if len(time_where_data_vector_less_zero) != 0 else np.inf
 
